@@ -7,38 +7,35 @@
 
 namespace MiX{
   /**
-   * ̾ݻNodeδ쥯饹
+   * OێNode̊NX
    *
-   * ̾˴ؤŪʥ󶡤
+   * OɊւ{IȃANZX񋟂
    */
-  template <class Char,class Traits,class XMLTraits>
-  class NamedNode : virtual public Node<Char,Traits,XMLTraits>{
+  template <class charT,class traitsT>
+  class NamedNode : virtual public Node<charT,traitsT>{
   public:
-    MiX_Template_Typedef(Char,Traits,XMLTraits);
-    typedef NamedNode<Char,Traits,XMLTraits> this_type;
+    MiX_Template_Typedef(charT,traitsT);
+    typedef NamedNode<charT,traitsT> this_type;
   private:
     string_type name_;
     /**
-     * ԡ󥹥ȥ饯
+     * Rs[RXgN^
      *
-     * 饤ȤϤƤӽФʤĤޤꥳԡǤʤ
+     * NCAg͂ĂяoȂB܂Rs[łȂB
      */
     NamedNode(const this_type& src){ };
   protected:
-    ///󥹥ȥ饯
+    ///RXgN^
     NamedNode(const string_type& name){ setName(name); }
   public:
-    ///ǥȥ饯
+    ///fXgN^
     virtual ~NamedNode()throw(){ };
-    ///̾ꤷޤ
+    ///Oݒ肵܂
     void setName(const string_type& name){name_ = name;};
-    ///̾ޤ
+    ///O𓾂܂
     string_type getName() const{return name_;};
   };
 }
 
-#ifndef MIX_NAMEDNODE_CPP_
-#include "NamedNode.cpp"
-#endif
 
 #endif
